:root {
  --django-filtering-ui-primary-light: #fff;
  --django-filtering-ui-primary-dark: #000;
  --django-filtering-ui-primary: var(--django-filtering-ui-primary-light);
  --django-filtering-ui-primary-inverse: var(
    --django-filtering-ui-primary-dark
  );
  --django-filtering-ui-secondary: #ffc20e;
  --django-filtering-ui-secondary-shaded: rgba(255, 194, 14, 0.4);
  --django-filtering-ui-tertiary: #e07e26;
  --django-filtering-ui-tertiary-shaded: rgba(224, 126, 39, 0.2);
  --django-filtering-ui-shaded: #494948;
  --django-filtering-ui-shaded-more: #acacac;
}
