{% load entrypoint vue_provide from django_filtering_ui %}

{% entrypoint entrypoint %}
{% vue_provide 'model-filtering-url' filtering_url %}
{% vue_provide 'model-listing-url' listing_url %}
{% vue_provide 'filtering-options-schema' filtering_options_schema quote=false %}
{% vue_provide 'filtering-json-schema' filtering_json_schema quote=false %}
{% vue_provide 'debug-enabled' DEBUG quote=false %}
